"use strict";

require("core-js/modules/es.symbol.to-primitive.js");
require("core-js/modules/es.date.to-primitive.js");
require("core-js/modules/es.symbol.js");
require("core-js/modules/es.symbol.description.js");
require("core-js/modules/es.number.constructor.js");
require("core-js/modules/es.object.define-property.js");
require("core-js/modules/es.object.get-own-property-descriptor.js");
require("core-js/modules/es.object.get-own-property-descriptors.js");
require("core-js/modules/es.object.define-properties.js");
require("core-js/modules/es.symbol.iterator.js");
require("core-js/modules/es.array.iterator.js");
require("core-js/modules/es.string.iterator.js");
require("core-js/modules/web.dom-collections.iterator.js");
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.mergeState = exports.default = void 0;
require("core-js/modules/es.object.to-string.js");
require("core-js/modules/web.dom-collections.for-each.js");
require("core-js/modules/es.object.keys.js");
require("core-js/modules/es.array.includes.js");
require("core-js/modules/es.string.includes.js");
require("core-js/modules/es.array.filter.js");
require("core-js/modules/es.array.map.js");
var _moveHighlighted = _interopRequireDefault(require("../utils/moveHighlighted"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return _typeof(key) === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (_typeof(input) !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (_typeof(res) !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
var mergeState = function mergeState(state, merge) {
  var newState = state;
  Object.keys(merge).forEach(function (key) {
    if (newState[key] !== merge[key]) newState = _objectSpread(_objectSpread({}, newState), {}, _defineProperty({}, key, merge[key]));
  });
  return newState;
};

// reducer param for testing
exports.mergeState = mergeState;
var selectReducer = function selectReducer(state, action) {
  var reducer = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : selectReducer;
  if (action.props == null) throw new Error("must always send props");
  var areOptionsOpen = state.areOptionsOpen,
    searchText = state.searchText,
    optionHighlighted = state.optionHighlighted,
    selectionHighlighted = state.selectionHighlighted,
    filteredOptions = state.filteredOptions;
  var type = action.type,
    props = action.props,
    payload = action.payload;
  var newState = state;
  switch (type) {
    case "openOptions":
      if (areOptionsOpen) return newState;
      newState = mergeState(newState, {
        areOptionsOpen: true
      });
      newState = reducer(newState, {
        props: props,
        type: "setValidOptionHighlighted"
      });
      newState = reducer(newState, {
        props: props,
        type: "updatePlaceholder"
      });
      if (props.singleNoOptions && props.hasSelection && searchText === "") {
        // On single creatable with no options, edit the currently selected label
        newState = reducer(newState, {
          props: props,
          type: "setSearchText",
          payload: props.selection[0].label
        });
      }
      return newState;
    case "closeOptions":
      if (!areOptionsOpen) return newState;
      newState = mergeState(newState, {
        areOptionsOpen: false
      });
      newState = reducer(newState, {
        props: props,
        type: "clearOptionHighlighted"
      });
      newState = reducer(newState, {
        props: props,
        type: "clearSearchText"
      });
      return newState;
    case "setSearchText":
      if (searchText === payload) return newState;
      newState = mergeState(newState, {
        searchText: payload
      });
      newState = reducer(newState, {
        props: props,
        type: "filterOptions"
      });
      return newState;
    case "clearSearchText":
      return reducer(newState, {
        props: props,
        type: "setSearchText",
        payload: ""
      });
    case "updatePlaceholder":
      var newPlaceholder = areOptionsOpen && !props.multiple && props.hasOptions && props.hasSelection ? props.selection[0].label // Set placeholder to current selection on single select
      : props.text_placeholder;
      return mergeState(newState, {
        placeholder: newPlaceholder
      });
    case "setWidth":
      var ref = payload;
      return mergeState(newState, {
        width: ref && ref.current ? ref.current.offsetWidth : 0
      });
    case "selectionUpdated":
      if (!props.hasSelection) {
        newState = reducer(newState, {
          props: props,
          type: "clearSelectionHighlighted"
        });
      }
      newState = reducer(newState, {
        props: props,
        type: "updatePlaceholder"
      });
      return reducer(newState, {
        props: props,
        type: "filterOptions"
      });
    case "clearOptionHighlighted":
      return mergeState(newState, {
        optionHighlighted: null
      });
    case "clearSelectionHighlighted":
      return mergeState(newState, {
        selectionHighlighted: null
      });
    case "setOptionHighlighted":
      if (payload == null) return newState;
      if (!areOptionsOpen || !filteredOptions.length) return reducer(newState, {
        props: props,
        type: "clearHighlighted"
      });
      return mergeState(newState, {
        optionHighlighted: payload,
        selectionHighlighted: null
      });
    case "setSelectionHighlighted":
      if (payload == null) return newState;
      if (!props.hasSelection) return reducer(newState, {
        props: props,
        type: "clearHighlighted"
      });
      return mergeState(newState, {
        selectionHighlighted: payload,
        optionHighlighted: null
      });
    case "clearHighlighted":
      return mergeState(newState, {
        selectionHighlighted: null,
        optionHighlighted: null
      });
    case "moveSelectionHighlighted":
      {
        return reducer(newState, {
          props: props,
          type: "setSelectionHighlighted",
          payload: (0, _moveHighlighted.default)(props.selection, payload, selectionHighlighted, true)
        });
      }
    case "moveOptionHighlighted":
      {
        return reducer(newState, {
          props: props,
          type: "setOptionHighlighted",
          payload: (0, _moveHighlighted.default)(filteredOptions, payload, optionHighlighted)
        });
      }
    case "setValidOptionHighlighted":
      if (!areOptionsOpen || selectionHighlighted != null || filteredOptions.map(function (option) {
        return option.value;
      }).filter(function (value) {
        return value != null;
      }).includes(optionHighlighted)) {
        return newState;
      }
      return reducer(newState, {
        props: props,
        type: "moveOptionHighlighted",
        payload: 0
      });
    case "filterOptions":
      var newFilteredOptions = props.filterOptions(props, searchText);
      if (props.creatable && searchText && !newFilteredOptions.some(function (option) {
        return option.value === searchText;
      }) && (props.allowDuplicates || !props.selection.some(function (item) {
        return item.value === searchText;
      }))) {
        // Don't allow duplicates
        newFilteredOptions.push({
          value: searchText,
          label: props.text_create + " \"".concat(searchText, "\"")
        }); // Add option for creatable
      }

      newState = mergeState(newState, {
        filteredOptions: newFilteredOptions
      });
      if (optionHighlighted == null) {
        newState = reducer(newState, {
          props: props,
          type: "setValidOptionHighlighted"
        });
      } else if (!newFilteredOptions.length) {
        newState = reducer(newState, {
          props: props,
          type: "clearOptionHighlighted"
        });
      }
      return newState;
    default:
      throw new Error("action not found: " + type);
  }
};
var _default = selectReducer;
exports.default = _default;