"use strict";

var _callOnChange = _interopRequireDefault(require("./callOnChange"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
// import massageDataOut from "./massageDataOut";
//
// jest.mock("./massageDataOut");
// massageDataOut.mockImplementation(() => (_, value) => value);

var props;
var expected;
beforeEach(function () {
  props = {
    multiple: false,
    options: [],
    selection: [],
    name: "test",
    massageDataOut: function massageDataOut(_, value) {
      return value;
    },
    onChange: jest.fn()
  };
  expected = {
    target: {
      value: [],
      name: "test"
    }
  };
});
it("should default", function () {
  (0, _callOnChange.default)(props, [], "add");
  expect(props.onChange).toBeCalledWith(expected);
});
describe("replace", function () {
  it("should replace", function () {
    (0, _callOnChange.default)(props, ["replacement"], "replace");
    expected.target.value = ["replacement"];
    expect(props.onChange).toBeCalledWith(expected);
  });
  it("should replace without array", function () {
    (0, _callOnChange.default)(props, "replacement", "replace");
    expected.target.value = ["replacement"];
    expect(props.onChange).toBeCalledWith(expected);
  });
});
describe("add", function () {
  it("should replace, when not multiple", function () {
    (0, _callOnChange.default)(props, ["replacement"], "add");
    expected.target.value = ["replacement"];
    expect(props.onChange).toBeCalledWith(expected);
  });
  it("should replace, when not multiple without array", function () {
    (0, _callOnChange.default)(props, "replacement", "add");
    expected.target.value = ["replacement"];
    expect(props.onChange).toBeCalledWith(expected);
  });
  it("should add, when multiple", function () {
    props.multiple = true;
    props.selection = [{
      value: "1",
      label: "1"
    }];
    props.options = [{
      value: "1",
      label: "1"
    }, {
      value: "2",
      label: "2"
    }];
    (0, _callOnChange.default)(props, "2", "add");
    expected.target.value = ["1", "2"];
    expect(props.onChange).toBeCalledWith(expected);
  });
  it("should remove child when adding parent", function () {
    props.multiple = true;
    props.selection = [{
      value: "child0.0",
      label: "child0.0",
      group: "0.0"
    }, {
      value: "nothing",
      label: "nothing"
    }];
    props.options = [{
      value: "parent",
      label: "parent",
      childGroup: "0"
    }, {
      value: "child0",
      label: "child0",
      group: "0",
      childGroup: "0.0"
    }, {
      value: "child0.0",
      label: "child0.0",
      group: "0.0"
    }, {
      value: "nothing",
      label: "nothing"
    }];
    (0, _callOnChange.default)(props, "child0", "add");
    expected.target.value = ["nothing", "child0"];
    expect(props.onChange).toBeCalledWith(expected);
  });
  it("should remove child when adding parent's parent", function () {
    props.multiple = true;
    props.selection = [{
      value: "child0.0",
      label: "child0.0",
      group: "0.0"
    }];
    props.options = [{
      value: "parent",
      label: "parent",
      childGroup: "0"
    }, {
      value: "child0",
      label: "child0",
      group: "0",
      childGroup: "0.0"
    }, {
      value: "child0.0",
      label: "child0.0",
      group: "0.0"
    }];
    (0, _callOnChange.default)(props, "parent", "add");
    expected.target.value = ["parent"];
    expect(props.onChange).toBeCalledWith(expected);
  });
});
describe("remove", function () {
  it("should remove", function () {
    (0, _callOnChange.default)(props, ["replacement"], "remove");
    expect(props.onChange).toBeCalledWith(expected);
  });
  it("should remove, without array", function () {
    (0, _callOnChange.default)(props, "replacement", "remove");
    expect(props.onChange).toBeCalledWith(expected);
  });
  it("should remove, when multiple", function () {
    props.multiple = true;
    props.selection = [{
      value: "1",
      label: "1"
    }, {
      value: "2",
      label: "2"
    }];
    (0, _callOnChange.default)(props, ["1"], "remove");
    expected.target.value = ["2"];
    expect(props.onChange).toBeCalledWith(expected);
  });
});