"use strict";

require("core-js/modules/es.object.define-property.js");
require("core-js/modules/es.object.keys.js");
require("core-js/modules/es.array.filter.js");
require("core-js/modules/es.object.get-own-property-descriptor.js");
require("core-js/modules/web.dom-collections.for-each.js");
require("core-js/modules/es.object.get-own-property-descriptors.js");
require("core-js/modules/es.object.define-properties.js");
require("core-js/modules/es.symbol.iterator.js");
require("core-js/modules/es.array.iterator.js");
require("core-js/modules/es.string.iterator.js");
require("core-js/modules/web.dom-collections.iterator.js");
require("core-js/modules/es.symbol.to-primitive.js");
require("core-js/modules/es.date.to-primitive.js");
require("core-js/modules/es.symbol.js");
require("core-js/modules/es.symbol.description.js");
require("core-js/modules/es.object.to-string.js");
require("core-js/modules/es.number.constructor.js");
var _massageDataIn = _interopRequireDefault(require("./massageDataIn"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return _typeof(key) === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (_typeof(input) !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (_typeof(res) !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
var props;
var expectedProps;
var funcValueKey = function funcValueKey(obj) {
  return obj["value"];
};
var funcLabelKey = function funcLabelKey(obj) {
  return obj["label"];
};
var funcOptionKey = function funcOptionKey(obj) {
  return obj["options"];
};
beforeEach(function () {
  props = {
    selection: "",
    options: [],
    placeholder: "placeholder",
    allowDuplicates: true,
    valueKey: funcValueKey,
    labelKey: funcLabelKey,
    optionsKey: funcOptionKey
  };
  expectedProps = {
    hasOptionGroups: false,
    hasOptions: false,
    hasSelection: false,
    allowDuplicates: true,
    selection: [],
    options: expect.anything(),
    hierarchicalOptions: expect.anything(),
    singleNoOptions: false,
    text_placeholder: "placeholder",
    valueKey: funcValueKey,
    labelKey: funcLabelKey,
    optionsKey: funcOptionKey
  };
});
it("should set text_placeholder from text_placeholder", function () {
  props.text_placeholder = "text_placeholder";
  expect((0, _massageDataIn.default)(props)).toStrictEqual(_objectSpread(_objectSpread({}, expectedProps), {}, {
    text_placeholder: "text_placeholder"
  }));
});
it("should set singleNoOptions", function () {
  props.creatable = true;
  props.multiple = false;
  expect((0, _massageDataIn.default)(props)).toStrictEqual(_objectSpread(_objectSpread({}, expectedProps), {}, {
    creatable: true,
    multiple: false,
    singleNoOptions: true
  }));
});
describe("selection", function () {
  it("empty values should always be an array", function () {
    expect((0, _massageDataIn.default)(props)).toStrictEqual(expectedProps);
  });
  it("single value should always be an array of objects", function () {
    props.selection = "1";
    expect((0, _massageDataIn.default)(props)).toStrictEqual(_objectSpread(_objectSpread({}, expectedProps), {}, {
      hasSelection: true,
      selection: [{
        label: "1",
        value: "1"
      }]
    }));
  });
  it("should always convert to strings", function () {
    props.selection = [1, 2];
    expect((0, _massageDataIn.default)(props)).toStrictEqual(_objectSpread(_objectSpread({}, expectedProps), {}, {
      hasSelection: true,
      selection: [{
        label: "1",
        value: "1"
      }, {
        label: "2",
        value: "2"
      }]
    }));
  });
  it("should hydrate selection from options", function () {
    props.selection = [1, 2];
    props.options = [{
      label: "One",
      value: "1"
    }, {
      label: "Two",
      value: "2"
    }];
    expect((0, _massageDataIn.default)(props)).toStrictEqual(_objectSpread(_objectSpread({}, expectedProps), {}, {
      hasSelection: true,
      hasOptions: true,
      selection: [{
        label: "One",
        value: "1"
      }, {
        label: "Two",
        value: "2"
      }]
    }));
  });
});
describe("option groups", function () {
  var optionGroups = [{
    label: "Parent 1",
    value: "1",
    options: [{
      label: "P1 Child 1",
      value: "p1child1"
    }]
  }, {
    label: "Parent 2 without child options",
    value: 2
  }, {
    label: "Parent 3 without value",
    options: [{
      label: "P3 Child 1",
      value: "p3child1"
    }]
  }];
  it("should hydrate selection with nested option groups", function () {
    props.options = optionGroups;
    props.selection = [1, "p1child1", "2", "created"];
    expect((0, _massageDataIn.default)(props)).toStrictEqual(_objectSpread(_objectSpread({}, expectedProps), {}, {
      hasOptionGroups: true,
      hasOptions: true,
      hasSelection: true,
      selection: [{
        label: "Parent 1",
        childGroup: "0",
        value: "1",
        options: expect.anything()
      }, {
        group: "0",
        label: "P1 Child 1",
        value: "p1child1"
      }, {
        label: "Parent 2 without child options",
        value: "2"
      }, {
        label: "created",
        value: "created"
      }]
    }));
  });
});