"use strict";

require("core-js/modules/es.string.starts-with.js");
require("core-js/modules/es.string.ends-with.js");
require("core-js/modules/es.array.includes.js");
require("core-js/modules/es.string.includes.js");
require("core-js/modules/es.array.iterator.js");
require("core-js/modules/es.object.to-string.js");
require("core-js/modules/es.set.js");
require("core-js/modules/es.string.iterator.js");
require("core-js/modules/esnext.set.add-all.js");
require("core-js/modules/esnext.set.delete-all.js");
require("core-js/modules/esnext.set.difference.js");
require("core-js/modules/esnext.set.every.js");
require("core-js/modules/esnext.set.filter.js");
require("core-js/modules/esnext.set.find.js");
require("core-js/modules/esnext.set.intersection.js");
require("core-js/modules/esnext.set.is-disjoint-from.js");
require("core-js/modules/esnext.set.is-subset-of.js");
require("core-js/modules/esnext.set.is-superset-of.js");
require("core-js/modules/esnext.set.join.js");
require("core-js/modules/esnext.set.map.js");
require("core-js/modules/esnext.set.reduce.js");
require("core-js/modules/esnext.set.some.js");
require("core-js/modules/esnext.set.symmetric-difference.js");
require("core-js/modules/esnext.set.union.js");
require("core-js/modules/web.dom-collections.iterator.js");
var _utils = require("./utils");
describe("rankFilterSort", function () {
  var items;
  var searchTerm;
  var sortComparator;
  var calculateRankThunk;
  beforeEach(function () {
    items = [];
    searchTerm = "";
    sortComparator = function sortComparator(a, b) {
      return a.rank - b.rank || a.label.localeCompare(b.label);
    }; // sort by rank, then alphabetically

    calculateRankThunk = function calculateRankThunk(searchTerm) {
      return function (option) {
        searchTerm = searchTerm.toLowerCase();
        if (option.label.toLowerCase() === searchTerm) return 8;else if (option.label.toLowerCase().startsWith(searchTerm)) return 4;else if (option.label.toLowerCase().endsWith(searchTerm)) return 2;else if (option.label.toLowerCase().includes(searchTerm)) return 1;else return 0;
      };
    };
  });
  it("should filter by label equals", function () {
    items = [{
      label: "test",
      value: "1"
    }, {
      label: "not",
      value: "not"
    }];
    searchTerm = "test";
    expect((0, _utils.rankFilterSort)(items, calculateRankThunk(searchTerm))).toStrictEqual([{
      label: "test",
      value: "1"
    }]);
  });
  it("should filter by label includes search term", function () {
    items = [{
      label: "testing",
      value: "1"
    }, {
      label: "not",
      value: "not"
    }];
    searchTerm = "test";
    expect((0, _utils.rankFilterSort)(items, calculateRankThunk(searchTerm))).toStrictEqual([{
      label: "testing",
      value: "1"
    }]);
  });
  it("should not filter by value includes search term", function () {
    items = [{
      label: "1",
      value: "testing"
    }, {
      label: "not",
      value: "not"
    }];
    searchTerm = "test";
    expect((0, _utils.rankFilterSort)(items, calculateRankThunk(searchTerm))).toStrictEqual([]);
  });
  it("should keep parents of child search term", function () {
    items = [{
      label: "Parent 1",
      value: "1",
      children: [{
        label: "P1 Child 1",
        value: "p1child1",
        children: [{
          label: "search",
          value: "p1c1child1"
        }]
      }]
    }, {
      label: "search",
      value: "2",
      children: [{
        label: "P2 child 2",
        value: "p2child1"
      }]
    }];
    searchTerm = "search";
    expect((0, _utils.rankFilterSort)(items, calculateRankThunk(searchTerm))).toStrictEqual([{
      label: "Parent 1",
      value: "1",
      children: [{
        label: "P1 Child 1",
        value: "p1child1",
        children: [{
          label: "search",
          value: "p1c1child1"
        }]
      }]
    }, {
      label: "search",
      value: "2"
    }]);
  });
  it("should sort parent with multiple children rank first", function () {
    items = [{
      label: "Parent 1",
      value: "1",
      children: [{
        label: "search",
        value: "p1child2"
      }]
    }, {
      label: "search",
      value: "2",
      children: [{
        label: "P2 child 2",
        value: "p2child1"
      }]
    }, {
      label: "Parent 3",
      value: "3",
      children: [{
        label: "P3 Child 1",
        value: "p3child1",
        children: [{
          label: "search",
          value: "p3c1child1"
        }]
      }, {
        label: "search",
        value: "p3child2"
      }]
    }];
    searchTerm = "search";
    expect((0, _utils.rankFilterSort)(items, calculateRankThunk(searchTerm))).toStrictEqual([{
      label: "Parent 3",
      value: "3",
      children: [{
        label: "P3 Child 1",
        value: "p3child1",
        children: [{
          label: "search",
          value: "p3c1child1"
        }]
      }, {
        label: "search",
        value: "p3child2"
      }]
    }, {
      label: "Parent 1",
      value: "1",
      children: [{
        label: "search",
        value: "p1child2"
      }]
    }, {
      label: "search",
      value: "2"
    }]);
  });
  it("should remove empty parents", function () {
    items = [{
      label: "Parent 1",
      value: "1",
      children: [{
        label: "P1 Child 1",
        value: "p1child1",
        children: [{
          label: "search",
          value: "p1c1child1"
        }]
      }]
    }, {
      label: "search",
      value: "2",
      children: [{
        label: "P2 child 2",
        value: "p2child1"
      }]
    }];
    searchTerm = "P2 child 2";
    expect((0, _utils.rankFilterSort)(items, calculateRankThunk(searchTerm))).toStrictEqual([{
      label: "search",
      value: "2",
      children: [{
        label: "P2 child 2",
        value: "p2child1"
      }]
    }]);
  });
  it("should do custom on rank 0 parents", function () {
    items = [{
      label: "rank 0 parent",
      value: "1",
      children: [{
        label: "search",
        value: "2"
      }]
    }];
    searchTerm = "P2 child 2";
    expect((0, _utils.rankFilterSort)(items, calculateRankThunk("search"), function (a, b) {
      return b.rank - a.rank;
    }, "children", function (item) {
      delete item.value;
      return item;
    })).toStrictEqual([{
      label: "rank 0 parent",
      children: [{
        label: "search",
        value: "2"
      }]
    }]);
  });
  it("should sort options in order", function () {
    items = [{
      label: "nothing",
      value: "0"
    }, {
      label: "_search_",
      value: "1"
    }, {
      label: "_search",
      value: "2"
    }, {
      label: "search_",
      value: "3"
    }, {
      label: "search",
      value: "4"
    }];
    searchTerm = "search";
    expect((0, _utils.rankFilterSort)(items, calculateRankThunk(searchTerm))).toStrictEqual([{
      label: "search",
      value: "4"
    }, {
      label: "search_",
      value: "3"
    }, {
      label: "_search",
      value: "2"
    }, {
      label: "_search_",
      value: "1"
    }]);
  });
  it("should custom sort options in order", function () {
    items = [{
      label: "nothing",
      value: "0"
    }, {
      label: "nothing",
      value: "p",
      options: [{
        label: "_search_",
        value: "p1"
      }, {
        label: "_search",
        value: "p2"
      }, {
        label: "search_",
        value: "p3"
      }, {
        label: "search",
        value: "p4"
      }, {
        label: "Zsort_search_",
        value: "p5"
      }, {
        label: "Asort_search_",
        value: "p6"
      }]
    }, {
      label: "_search_",
      value: "1"
    }, {
      label: "_search",
      value: "2"
    }, {
      label: "search_",
      value: "3"
    }, {
      label: "search",
      value: "4"
    }, {
      label: "Zsort_search_",
      value: "6"
    }, {
      label: "Asort_search_",
      value: "5"
    }];
    searchTerm = "search";
    sortComparator = function sortComparator(a, b) {
      return b.rank - a.rank || a.item.label.localeCompare(b.item.label);
    };
    var childrenKey = "options";
    expect((0, _utils.rankFilterSort)(items, calculateRankThunk(searchTerm), sortComparator, childrenKey)).toStrictEqual([{
      label: "nothing",
      value: "p",
      options: [{
        label: "search",
        value: "p4"
      }, {
        label: "search_",
        value: "p3"
      }, {
        label: "_search",
        value: "p2"
      }, {
        label: "_search_",
        value: "p1"
      }, {
        label: "Asort_search_",
        value: "p6"
      }, {
        label: "Zsort_search_",
        value: "p5"
      }]
    }, {
      label: "search",
      value: "4"
    }, {
      label: "search_",
      value: "3"
    }, {
      label: "_search",
      value: "2"
    }, {
      label: "_search_",
      value: "1"
    }, {
      label: "Asort_search_",
      value: "5"
    }, {
      label: "Zsort_search_",
      value: "6"
    }]);
  });
});
describe("inRange", function () {
  it("should default range at 0 without end, false", function () {
    expect((0, _utils.inRange)(-1, 5)).toBe(false);
  });
  it("should default range at 0 without end, true", function () {
    expect((0, _utils.inRange)(3, 5)).toBe(true);
  });
  it("should be in range", function () {
    expect((0, _utils.inRange)(5, 4, 6)).toBe(true);
  });
  it("should be in range start", function () {
    expect((0, _utils.inRange)(4, 4, 6)).toBe(true);
  });
  it("should not be in range end", function () {
    expect((0, _utils.inRange)(6, 4, 6)).toBe(false);
  });
});
describe("without", function () {
  it("should do nothing, if empty", function () {
    var testArray = [];
    expect((0, _utils.without)(testArray, 0)).toBe(testArray);
    expect((0, _utils.without)(testArray, 0)).toStrictEqual([]);
  });
  it("should do nothing", function () {
    expect((0, _utils.without)([1, 2, 3], 0)).toStrictEqual([1, 2, 3]);
  });
  it("should remove", function () {
    expect((0, _utils.without)([1, 2], 1)).toStrictEqual([2]);
  });
  it("should remove many", function () {
    expect((0, _utils.without)(["1", "2", "4"], ["2", "4"])).toStrictEqual(["1"]);
  });
});
describe("castArray", function () {
  it("should be array", function () {
    expect((0, _utils.castArray)(1)).toStrictEqual([1]);
  });
  it("should not change", function () {
    var array = [1];
    expect((0, _utils.castArray)(array)).toBe(array);
    expect((0, _utils.castArray)(array)).toStrictEqual([1]);
  });
});
describe("isEmpty", function () {
  it("should be empty, string", function () {
    expect((0, _utils.isEmpty)("")).toBe(true);
  });
  it("should not be empty, string", function () {
    expect((0, _utils.isEmpty)("1")).toBe(false);
  });
  it("should be empty, array", function () {
    expect((0, _utils.isEmpty)([])).toBe(true);
  });
  it("should not be empty, array", function () {
    expect((0, _utils.isEmpty)([1])).toBe(false);
  });
  it("should be empty, object", function () {
    expect((0, _utils.isEmpty)({})).toBe(true);
  });
  it("should not be empty, object", function () {
    expect((0, _utils.isEmpty)({
      key: "value"
    })).toBe(false);
  });
  it("should be empty, size", function () {
    expect((0, _utils.isEmpty)(new Set())).toBe(true);
  });
  it("should not be empty, size", function () {
    var withSize = new Set();
    withSize.add(1);
    expect((0, _utils.isEmpty)(withSize)).toBe(false);
  });
  it("should be empty, null", function () {
    expect((0, _utils.isEmpty)(null)).toBe(true);
  });
  it("should be empty, undefined", function () {
    expect((0, _utils.isEmpty)(undefined)).toBe(true);
  });
  it("should not be empty, number", function () {
    expect((0, _utils.isEmpty)(0)).toBe(false);
  });
});
describe("last", function () {
  it("should be last item", function () {
    expect((0, _utils.last)(["first", "last"])).toBe("last");
  });
  it("should be only item", function () {
    expect((0, _utils.last)(["only"])).toBe("only");
  });
  it("should be nothing", function () {
    expect((0, _utils.last)([])).toBeUndefined();
  });
});
describe("withKeys", function () {
  var testObject = {
    start: "",
    startsWith: "",
    notstarts: "",
    tarts: ""
  };
  it("should get keys starting with", function () {
    expect((0, _utils.withKeys)(testObject, "start")).toStrictEqual({
      start: "",
      startsWith: ""
    });
  });
  it("should get keys without starting with", function () {
    expect((0, _utils.withKeys)(testObject, "start", true)).toStrictEqual({
      notstarts: "",
      tarts: ""
    });
  });
});
describe("withoutKeys", function () {
  it("should get keys without", function () {
    var testObject = {
      start: "",
      startsWith: "",
      notstarts: "",
      tarts: ""
    };
    expect((0, _utils.withoutKeys)(testObject, "start")).toStrictEqual({
      notstarts: "",
      tarts: ""
    });
  });
});